# tests/test_info.py
#import sys, os
#curr_dir = os.path.dirname(__file__)
#rel_path = os.path.join(curr_dir, '../src')
#sys.path.insert(0, os.path.abspath(rel_path))

import unittest
from remah.info import ramah

class TestInfo(unittest.TestCase):
    
    def test_ramah(self):
        result = ramah()
        expected_result = 'Hello, I am remah ramah!'
        self.assertEqual(result, expected_result)

if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages

setup(
    name='remah',
    version='0.0.4',
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    install_requires=[
        # Your dependencies
    ],
    tests_require=[
        'unittest',
    ],
    test_suite='tests',
    entry_points={
        'console_scripts': [
            # If you have any console scripts, specify them here
        ],
    },
    url='https://github.com/dudung/remah',
    license='MIT',
    author='Sparisoma Viridi',
    author_email='dudung@gmail.com',
    description='python package for mixed modeling approaches',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
)
